#	OpenShot Video Editor is a program that creates, modifies, and edits video files.
#   Copyright (C) 2009  Jonathan Thomas
#
#	This file is part of OpenShot Video Editor (http://launchpad.net/openshot/).
#
#	OpenShot Video Editor is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation, either version 3 of the License, or
#	(at your option) any later version.
#
#	OpenShot Video Editor is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.


# Compile All PO Files into MO files, and create directory structure required
# by OpenShot's /locale/ folder.  Once you run this script, copy the folders
# into the /locale/ folder of OpenSHot.

import subprocess, sys, os, shutil

path = os.path.dirname(os.path.abspath(__file__))
locale_folder = os.path.join(path, "openshot", "locale", "OpenShot")

# Compile all PO files into MO files
subprocess.call('find -iname "*.po" -exec msgfmt {} -o {}.mo \;', shell=True)
#subprocess.call('find -iname "*.po" -exec po2ts {} -o {}.ts \;', shell=True)

# Loop through each MO file
for file in os.listdir(locale_folder):
	# only look for MO files
	if ".mo" in file or ".ts" in file or ".po" in file:
		# Get the culture code from the file name
		culture = str.split(file, ".")[0]
		extension = str.split(file, ".")[-1]

		# Create directory
		if not os.path.exists(os.path.join(locale_folder, culture)):
			os.mkdir(os.path.join(locale_folder, culture))
			os.mkdir(os.path.join(locale_folder, culture, "LC_MESSAGES"))
		
		# Convert PO to TS
		if extension == "po":
			# Create TS files (text)
			subprocess.call('QT_SELECT=qt4 lconvert -if po -of ts "%s" -o "%s"' % (os.path.join(locale_folder, file), os.path.join(locale_folder, "%s.ts" % culture)), shell=True)
			
			# Create QM files (binary)
			subprocess.call('QT_SELECT=qt4 lrelease "%s" -qm "%s"' % (os.path.join(locale_folder, "%s.ts" % culture), os.path.join(locale_folder, "%s.qm" % culture)), shell=True)
			
			# Copy TS and QM files to target folder
			shutil.copy(os.path.join(locale_folder, "%s.ts" % culture), os.path.join(locale_folder, culture, "LC_MESSAGES", "OpenShot.ts"))
			shutil.copy(os.path.join(locale_folder, "%s.qm" % culture), os.path.join(locale_folder, culture, "LC_MESSAGES", "OpenShot.qm"))
			os.remove(os.path.join(locale_folder, "%s.ts" % culture))
			os.remove(os.path.join(locale_folder, "%s.qm" % culture))
		
		# Copy file into the new folder
		shutil.copy(os.path.join(locale_folder, file), os.path.join(locale_folder, culture, "LC_MESSAGES", "OpenShot.%s" % extension))
		
		# Clean up files
		if extension == "po":
			# Make a copy of the PO file in the target folder
			shutil.copy(os.path.join(locale_folder, "%s.po" % culture), os.path.join(locale_folder, culture, "LC_MESSAGES", "OpenShot.po"))
		else:
			# Remove MO, and TS files from the root folder
			os.remove(os.path.join(locale_folder, file))
		
		